==> safecheck-3.0.14.jar: filiale/wuan/sqls/FetchPlanUserfiles.sql <==
SELECT uf.f_user_id       As    id,               --表档案id
       f_position         AS    f_weizhi,         --安装位置
       gb.f_manufacturers AS    f_maker,          --气表厂家
       gm.f_meter_style   AS    f_diaphgram_size, --气表型号
       gb.f_meter_brand   AS    f_aliasname,      --气表品牌
       gb.f_meter_type    AS    f_meter_type,     --气表类型
       f_meter_base       AS    f_prior_reading,  --气表底数
       f_meternumber      AS    f_meter_no,       --表号
       f_aroundmeter      AS    f_flow_direction, --左右表
       f_metertitles      As    f_metertitles,    --表封号
       f_meter_base       As    f_metergasnums,   --气表底数
       uf.f_initial_base  AS    f_initial_base,   --表基数
       uf.f_total_fee,                            --累购金额
       case when uf.f_meter_classify = '机表' then uf.f_meter_base else uf.f_total_gas end f_total_gas,--累购气量
       gb.f_collection_type,       --购气类型(按金额，按气量)
       f_meter_classify,
       u.f_last_check_state,
       u.f_last_check_date,
       u.f_last_check_result,
       uf.version,
       rc.f_operat_type,--拉黑类型
       rc.f_comments as f_commentsdata,--拉黑原因
       rc.f_operate_date,--操作时间
       rc.f_operator  --操作拉黑人
FROM t_userfiles uf
         LEFT JOIN t_user_address u on uf.f_userinfo_id = u.f_userinfo_id
         LEFT JOIN (select *
                    from (select *,
                                 ROW_NUMBER() OVER ( partition BY f_userinfo_id ORDER BY f_operate_date DESC ) AS rn
                          from t_record) rc
                    where rn = 1) rc on uf.f_userinfo_id = rc.f_userinfo_id --拉黑操作记录表
         LEFT JOIN t_gasbrand gb ON uf.f_gasbrand_id = gb.id
         LEFT JOIN t_gasmodel gm on uf.f_gasmodel_id = gm.id
WHERE uf.f_userinfo_id = '{f_userid}'
  and (uf.f_table_state = '正常' or uf.f_table_state = '停用')

==> safecheck-3.0.72.jar: filiale/wuan/sqls/FetchPlanUserfiles.sql <==
SELECT uf.f_user_id       As    id,               --表档案id
       f_position         AS    f_weizhi,         --安装位置
       gb.f_manufacturers AS    f_maker,          --气表厂家
       gm.f_meter_style   AS    f_diaphgram_size, --气表型号
       gb.f_meter_brand   AS    f_aliasname,      --气表品牌
       gb.f_meter_type    AS    f_meter_type,     --气表类型
       f_meter_base       AS    f_prior_reading,  --气表底数
       f_meternumber      AS    f_meter_no,       --表号
       f_aroundmeter      AS    f_flow_direction, --左右表
       f_metertitles      As    f_metertitles,    --表封号
       f_meter_base       As    f_metergasnums,   --气表底数
       uf.f_initial_base  AS    f_initial_base,   --表基数
       uf.f_total_fee,                            --累购金额
       case when uf.f_meter_classify = '机表' then uf.f_meter_base else uf.f_total_gas end f_total_gas,--累购气量
       gb.f_collection_type,       --购气类型(按金额，按气量)
       f_meter_classify,
       u.f_last_check_state,
       u.f_last_check_date,
       u.f_last_check_result,
       uf.version,
       rc.f_operat_type,--拉黑类型
       rc.f_comments as f_commentsdata,--拉黑原因
       rc.f_operate_date,--操作时间
       rc.f_operator,  --操作拉黑人
       tdil1.f_item_value as f_old_yyql
FROM t_userfiles uf
         LEFT JOIN t_user_address u on uf.f_userinfo_id = u.f_userinfo_id
         LEFT JOIN (select *
                    from (select *,
                                 ROW_NUMBER() OVER ( partition BY f_userinfo_id ORDER BY f_operate_date DESC ) AS rn
                          from t_record) rc
                    where rn = 1) rc on uf.f_userinfo_id = rc.f_userinfo_id --拉黑操作记录表
         LEFT JOIN t_gasbrand gb ON uf.f_gasbrand_id = gb.id
         LEFT JOIN t_gasmodel gm on uf.f_gasmodel_id = gm.id
         LEFT JOIN t_check_paper tcp on tcp.f_userinfoid = uf.f_userinfo_id and tcp.f_upload_date = (select max (f_upload_date) from t_check_paper where f_userinfoid = '{f_userid}' and f_entry_status='入户')
         left join t_paper_devices tpd on tcp.id = tpd.f_paper_id and tpd.f_device_type ='燃气表'
         left join t_devices_items tdi1 on tpd.id = tdi1.f_device_id and tdi1.f_item_name = '已用气量'
         left join t_devices_items_lists tdil1 on tdi1.id = tdil1.f_item_id
WHERE uf.f_userinfo_id = '{f_userid}'
  and (uf.f_table_state = '正常' or uf.f_table_state = '停用')
